==> discord-buttons-fixed-2.0.0.tgz: package/README.md <==
<div align="center">
  <h1>discord-buttons</h1>
  <p>
    <a href="https://www.npmjs.com/package/discord-buttons-fixed"><img src="https://img.shields.io/npm/v/discord-buttons-fixed?maxAge=3600" alt="NPM version" /></a>
    <a href="https://www.npmjs.com/package/discord-buttons-fixed"><img src="https://img.shields.io/npm/dt/discord-buttons-fixed?maxAge=3600" alt="NPM downloads" /></a>
  </p>
  <p>
    <a href="https://www.npmjs.com/package/discord-buttons-fixed"><img src="https://nodei.co/npm/discord-buttons.png?downloads=true&stars=true" alt="NPM Banner"></a>
  </p>
</div>
<div align="center">
  <img src="https://cdn.discordapp.com/attachments/846455339419172874/848300816288055296/Main.png">
  <br> <br>
</div>

## 📂 | Installation
```sh
npm i discord-buttons-fixed
```

## 📜 | Setup
```js
const discord = require('discord.js'); //Define the discord.js module
const client = new discord.Client(); //Creating discord.js client (constructor)
const disbut = require('discord-buttons-fixed');
disbut(client);
```

## ✍ | Examples
All of our Examples and Button Styles are in [examples.md]([http://](https://github.com/whoisbaby/discord-buttons-fixed/blob/main/examples.md))
Also you can check our [Documentation](https://discord-buttons.js.org), if you have any other problems/questions, you can join our [Support Server!](https://discord.gg/5JtyYqW)

## 👥 | Contact
<a href="https://www.youtube.com/channel/UCxxK71QFN4_PrBhCFmH2Jmw"><img widhtsrc="https://raw.githubusercontent.com/MikeCodesDotNET/ColoredBadges/master/png/streaming/youtube%402x.png"></a></br>
<a href="https://discord.gg/5JtyYqW"><img src="https://discord.com/api/guilds/748098690874474567/widget.png?style=banner1"></a>

==> discord-buttons-fixed-2.0.2.tgz: package/README.md <==
<div align="center">
  <h1>discord-buttons</h1>
  <p>
    <a href="https://www.npmjs.com/package/discord-buttons-fixed"><img src="https://img.shields.io/npm/v/discord-buttons-fixed?maxAge=3600" alt="NPM version" /></a>
    <a href="https://www.npmjs.com/package/discord-buttons-fixed"><img src="https://img.shields.io/npm/dt/discord-buttons-fixed?maxAge=3600" alt="NPM downloads" /></a>
  </p>
  <p>
    <a href="https://www.npmjs.com/package/discord-buttons-fixed"><img src="https://nodei.co/npm/discord-buttons-fixed.png?downloads=true&stars=true" alt="NPM Banner"></a>
  </p>
</div>
<div align="center">
  <img src="https://cdn.discordapp.com/attachments/846455339419172874/848300816288055296/Main.png">
  <br> <br>
</div>

## 📂 | Installation
```sh
npm i discord-buttons-fixed
```

## 📜 | Setup
```js
const discord = require('discord.js'); //Define the discord.js module
const client = new discord.Client(); //Creating discord.js client (constructor)
const disbut = require('discord-buttons-fixed');
disbut(client);
```

## ✍ | Examples
All of our Examples and Button Styles are in [examples.md]([http://](https://github.com/whoisbaby/discord-buttons-fixed/blob/main/examples.md))
Also you can check our [Documentation](https://discord-buttons.js.org), if you have any other problems/questions, you can join our [Support Server!](https://discord.gg/5JtyYqW)

## 👥 | Contact
<a href="https://www.youtube.com/channel/UCxxK71QFN4_PrBhCFmH2Jmw"><img widhtsrc="https://raw.githubusercontent.com/MikeCodesDotNET/ColoredBadges/master/png/streaming/youtube%402x.png"></a></br>
<a href="https://discord.gg/5JtyYqW"><img src="https://discord.com/api/guilds/748098690874474567/widget.png?style=banner1"></a>
